Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DB ¶
func (*DB) Exec ¶ added in v0.4.0
Exec delegates to the active transaction if present, otherwise to Conn.
func (*DB) Query ¶ added in v0.4.0
Query delegates to the active transaction if present, otherwise to Conn.
Click to show internal directories.
Click to hide internal directories.