Documentation
¶
Index ¶
- func AvailableThemes() []string
- func WriteJSON(w io.Writer, data any) error
- type Formatter
- func (f *Formatter) AreaCreated(a *area.Area)
- func (f *Formatter) AreaDeleted(a *area.Area)
- func (f *Formatter) AreaList(areas []area.Area)
- func (f *Formatter) AreaRenamed(oldName, newName string)
- func (f *Formatter) BulkEditPreview(tasks []task.Task)
- func (f *Formatter) BulkEditSummary(count int)
- func (f *Formatter) Error(msg string)
- func (f *Formatter) GroupedLogbook(tasks []task.Task, groupBy string)
- func (f *Formatter) GroupedTaskList(tasks []task.Task, groupBy string)
- func (f *Formatter) Logbook(tasks []task.Task)
- func (f *Formatter) ProjectAreaCleared(p *task.Task)
- func (f *Formatter) ProjectCreated(p *task.Task)
- func (f *Formatter) ProjectDeleted(p *task.Task)
- func (f *Formatter) ProjectDetails(p *task.Task)
- func (f *Formatter) ProjectEdited(name string, changes []string)
- func (f *Formatter) ProjectMoved(p *task.Task, areaName string)
- func (f *Formatter) ProjectRenamed(oldName, newName string)
- func (f *Formatter) ProjectsCompleted(results []task.CompleteResult)
- func (f *Formatter) ProjectsUncompleted(projects []task.Task)
- func (f *Formatter) SetHidePlannedDate(hide bool)
- func (f *Formatter) SetHideScope(hide bool)
- func (f *Formatter) TagDeleted(tagName string, count int64)
- func (f *Formatter) TagList(tags []string)
- func (f *Formatter) TaskCreated(t *task.Task)
- func (f *Formatter) TaskDetails(t *task.Task)
- func (f *Formatter) TaskDueDateSet(t *task.Task)
- func (f *Formatter) TaskEdited(id int64, changes []string)
- func (f *Formatter) TaskList(tasks []task.Task)
- func (f *Formatter) TaskPlannedDateSet(t *task.Task)
- func (f *Formatter) TaskRecurrenceEndSet(t *task.Task)
- func (f *Formatter) TaskRecurrenceInfo(t *task.Task)
- func (f *Formatter) TaskRecurrencePaused(t *task.Task)
- func (f *Formatter) TaskRecurrenceResumed(t *task.Task)
- func (f *Formatter) TaskRecurrenceSet(t *task.Task)
- func (f *Formatter) TaskTagAdded(t *task.Task, tagName string)
- func (f *Formatter) TaskTagRemoved(t *task.Task, tagName string)
- func (f *Formatter) TasksCompleted(results []task.CompleteResult)
- func (f *Formatter) TasksDeleted(tasks []task.Task)
- func (f *Formatter) TasksUncompleted(tasks []task.Task)
- type Icons
- type Theme
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AvailableThemes ¶
func AvailableThemes() []string
AvailableThemes returns a list of available preset theme names
Types ¶
type Formatter ¶
type Formatter struct {
// contains filtered or unexported fields
}
func (*Formatter) AreaCreated ¶
func (*Formatter) AreaDeleted ¶
func (*Formatter) AreaRenamed ¶
func (*Formatter) BulkEditPreview ¶
func (*Formatter) BulkEditSummary ¶
func (*Formatter) GroupedLogbook ¶
GroupedLogbook displays completed tasks grouped by the specified field. For date grouping, it uses CompletedAt instead of PlannedDate.
func (*Formatter) GroupedTaskList ¶
GroupedTaskList displays tasks grouped by the specified field. groupBy can be: "scope", "date", or "none" (falls back to TaskList)
func (*Formatter) ProjectAreaCleared ¶
func (*Formatter) ProjectCreated ¶
func (*Formatter) ProjectDeleted ¶
func (*Formatter) ProjectDetails ¶
func (*Formatter) ProjectEdited ¶
func (*Formatter) ProjectRenamed ¶
func (*Formatter) ProjectsCompleted ¶
func (f *Formatter) ProjectsCompleted(results []task.CompleteResult)
func (*Formatter) ProjectsUncompleted ¶
func (*Formatter) SetHidePlannedDate ¶
func (*Formatter) SetHideScope ¶
func (*Formatter) TagDeleted ¶
func (*Formatter) TaskCreated ¶
func (*Formatter) TaskDetails ¶
func (*Formatter) TaskDueDateSet ¶
func (*Formatter) TaskEdited ¶
func (*Formatter) TaskPlannedDateSet ¶
func (*Formatter) TaskRecurrenceEndSet ¶
func (*Formatter) TaskRecurrenceInfo ¶
func (*Formatter) TaskRecurrencePaused ¶
func (*Formatter) TaskRecurrenceResumed ¶
func (*Formatter) TaskRecurrenceSet ¶
func (*Formatter) TasksCompleted ¶
func (f *Formatter) TasksCompleted(results []task.CompleteResult)
func (*Formatter) TasksDeleted ¶
func (*Formatter) TasksUncompleted ¶
type Theme ¶
type Theme struct {
Muted lipgloss.Style
Accent lipgloss.Style
Warning lipgloss.Style
Success lipgloss.Style
Error lipgloss.Style
Header lipgloss.Style
ID lipgloss.Style
Scope lipgloss.Style
Icons Icons
}
Theme holds pre-built Lipgloss styles for consistent output formatting
func DefaultTheme ¶
func DefaultTheme() *Theme
DefaultTheme returns the default theme matching the original hardcoded values
func NewTheme ¶
func NewTheme(cfg *config.ThemeConfig) *Theme
NewTheme creates a Theme from config, using defaults for unset values
Click to show internal directories.
Click to hide internal directories.